@@ -21,6 +21,11 @@ class FieldValueError(ValueError):
     pass
 
 
+def sql():
+    import sqlalchemy
+    return sqlalchemy
+
+
 class Field(UnicodeMixin):
     '''Base class of all :mod:`.odm` Fields.
 
@@ -106,6 +111,7 @@ class Field(UnicodeMixin):
     '''
     repr_type = 'unknown'
     primary_key = False
+    autoincrement = False
     required = True
     to_python = None
     index = False
@@ -200,6 +206,11 @@ class Field(UnicodeMixin):
             raise TypeError(("__init__() got an unexepcted keyword argument "
                              "'{0}'".format(keys[0])))
 
+    def sql_alchemy_column(self):
+        '''Return a valid Column for :sqlalchemy:`SqlAlchemy model <>`.
+        '''
+        raise NotImplementedError
+
 
 class CharField(Field):
     repr_type = 'text'
@@ -212,10 +223,20 @@ class CharField(Field):
     to_store = to_python
     to_json = to_python
 
+    def sql_alchemy_column(self):
+        s = sql()
+        return s.Column(s.String, primary_key=self.primary_key,
+                        default=self._default, nullable=not self.required)
+
 
 class AutoIdField(Field):
     primary_key = True
 
+    def sql_alchemy_column(self):
+        s = sql()
+        return s.Column(s.Integer, primary_key=self.primary_key,
+                        default=self._default, nullable=not self.required)
+
 
 class IntegerField(Field):
     index = True
@@ -235,6 +256,12 @@ class IntegerField(Field):
 
     to_json = to_python
 
+    def sql_alchemy_column(self):
+        s = sql()
+        return s.Column(s.Integer, primary_key=self.primary_key,
+                        autoincrement=self.autoincrement,
+                        default=self._default, nullable=not self.required)
+
 
 class BooleanField(Field):
     index = True
@@ -252,6 +279,12 @@ class BooleanField(Field):
             value = self.get_default()
         return store.encode_bool(value)
 
+    def sql_alchemy_column(self):
+        s = sql()
+        return s.Column(s.Boolean, primary_key=self.primary_key,
+                        default=self._default,
+                        nullable=not self.required)
+
 
 class FloatField(Field):
     index = True
@@ -270,6 +303,11 @@ class FloatField(Field):
         else:
             return self.get_default()
 
+    def sql_alchemy_column(self):
+        s = sql()
+        return s.Column(s.Float, default=self._default,
+                        nullable=not self.required)
+
 
 class DateField(Field):
     repr_type = 'numeric'
@@ -298,6 +336,11 @@ class DateField(Field):
         self.auto_now = auto_now
         super(DateField, self)._handle_extras(**extras)
 
+    def sql_alchemy_column(self):
+        s = sql()
+        return s.Column(s.Date, default=self._default,
+                        nullable=not self.required)
+
 
 class DateTimeField(DateField):
 
@@ -312,6 +355,11 @@ class DateTimeField(DateField):
         else:
             return self.get_default()
 
+    def sql_alchemy_column(self):
+        s = sql()
+        return s.Column(s.DateTime, default=self._default,
+                        nullable=not self.required)
+
 
 class PickleField(Field):
     repr_type = 'bytes'
@@ -345,6 +393,11 @@ class PickleField(Field):
             if value is not None:
                 return b64encode(value).decode('utf-8')
 
+    def sql_alchemy_column(self):
+        s = sql()
+        return s.Column(s.PickleType, default=self._default,
+                        nullable=not self.required)
+
 
 class JSONField(CharField):
     '''A JSON field which implements automatic conversion to
@@ -447,6 +500,11 @@ class JSONField(CharField):
                 name = JSPLITTER.join((self.store_name, name))
             return (name, None)
 
+    def sql_alchemy_column(self):
+        s = sql()
+        return s.Column(s.Text, default=self._default,
+                        nullable=not self.required)
+
 
 class ForeignKey(Field):
     '''A :class:`.Field` defining a :ref:`one-to-many <one-to-many>`
