@@ -1,19 +1,8 @@
-'''\
-A Python implementation of JSON-RPC 2.0 Specification
-
-JSON-RPC is a lightweight remote procedure call protocol.
-It's designed to be simple.
-
-A remote method is invoked by sending a request to a remote service.
-The request is a single object serialized using JSON.
-
-The specification is at
-http://groups.google.com/group/json-rpc/web/json-rpc-2-0
-'''
 import sys
 from functools import partial
+import logging
 
-from pulsar import async, Failure, multi_async, maybe_failure
+from pulsar import AsyncObject, multi_async, task, coroutine_return
 from pulsar.utils.system import json
 from pulsar.utils.structures import AttributeDictionary
 from pulsar.utils.security import gen_unique_id
@@ -25,25 +14,35 @@ from pulsar.utils.httpurl import JSON_CONTENT_TYPES
 
 from .handlers import RpcHandler, InvalidRequest, exception
 
+
 __all__ = ['JSONRPC', 'JsonProxy']
 
 
-class JSONRPC(RpcHandler):
-    '''An :class:`RpcHandler` for class for JSON-RPC services.
-Design to comply with the `JSON-RPC 2.0`_ Specification.
+logger = logging.getLogger('pulsar.jsonrpc')
 
-.. _`JSON-RPC 2.0`: http://www.jsonrpc.org/
-'''
+
+class JSONRPC(RpcHandler):
+    '''An :class:`.RpcHandler` for JSON-RPC services.
+
+    Design to comply with the `JSON-RPC 2.0`_ Specification.
+
+    JSON-RPC is a lightweight remote procedure call protocol
+    designed to be simple.
+    A remote method is invoked by sending a request to a remote service,
+    the request is a single object serialised using JSON.
+
+    .. _`JSON-RPC 2.0`: http://www.jsonrpc.org/specification
+    '''
     version = '2.0'
-    methods = ('post',)
 
     def __call__(self, request):
         return Json(self._call(request)).http_response(request)
 
-    @async()
     def _call(self, request):
         response = request.response
         data = {}
+        exc_info = None
+        callable = None
         try:
             try:
                 data = yield request.body_data()
@@ -62,35 +61,33 @@ Design to comply with the `JSON-RPC 2.0`_ Specification.
             #
             callable = self.get_handler(data.get('method'))
             result = yield callable(request, *args, **kwargs)
-        except Exception:
-            result = sys.exc_info()
+        except Exception as exc:
+            result = exc
+            exc_info = sys.exc_info()
         #
-        result = maybe_failure(result)
         res = {'id': data.get('id'), "jsonrpc": self.version}
-        if isinstance(result, Failure):
+        if exc_info:
+            code = getattr(result, 'fault_code', -32603)
             msg = None
-            error = result.error
-            code = getattr(error, 'fault_code', -32603)
-            if isinstance(error, TypeError):
+            if isinstance(result, TypeError) and callable:
                 msg = checkarity(callable, args, kwargs, discount=1)
-            msg = msg or str(error) or 'JSON RPC exception'
+            msg = msg or str(result) or 'JSON RPC exception'
             if code == -32603:
-                result.log(msg=msg, level='error')
+                logger.error(msg, exc_info=exc_info)
             else:
-                result.log(msg=msg, level='warning')
-            result = {'code': code,
-                      'message': msg,
-                      'data': getattr(error, 'data', '')}
-            request.response.status_code = getattr(error, 'status', 500)
-            res['error'] = result
+                logger.warning(msg)
+            error = {'code': code,
+                     'message': msg,
+                     'data': getattr(result, 'data', '')}
+            response.status_code = getattr(result, 'status', 500)
+            res['error'] = error
         else:
             res['result'] = result
-        yield res
+        coroutine_return(res)
 
 
 class JsonCall:
-
-    dlots = ('_client', '_name')
+    slots = ('_client', '_name')
 
     def __init__(self, client, name):
         self._client = client
@@ -116,63 +113,60 @@ class JsonCall:
         return self._client._call(self._name, *args, **kwargs)
 
 
-class JsonProxy(object):
-    '''A python Proxy class for :class:`JSONRPC` Servers.
+class JsonProxy(AsyncObject):
+    '''A python Proxy class for :class:`.JSONRPC` Servers.
 
-:param url: server location
-:param version: JSONRPC server version. Default ``2.0``
-:param id: optional request id, generated if not provided. Default ``None``.
-:param data: Extra data to include in all requests. Default ``None``.
-:param full_response: return the full Http response rather than
-    just the content.
-:param http: optional http opener. If provided it must have the ``request``
-    method available which must be of the form::
+    :param url: server location
+    :param version: JSON-RPC server version. Default ``2.0``
+    :param id: optional request id, generated if not provided.
+        Default ``None``.
+    :param data: Extra data to include in all requests. Default ``None``.
+    :param full_response: return the full Http response rather than
+        just the content.
+    :param http: optional http client. If provided it must have the ``request``
+        method available which must be of the form::
 
-        http.request(url, body=..., method=...)
+            http.request(url, body=..., method=...)
 
-    Default ``None``.
+        Default ``None``.
 
-Lets say your RPC server is running at ``http://domain.name.com/``::
+    Lets say your RPC server is running at ``http://domain.name.com/``::
 
-    >>> a = JsonProxy('http://domain.name.com/')
-    >>> a.add(3,4)
-    7
-    >>> a.ping()
-    'pong'
+        >>> a = JsonProxy('http://domain.name.com/')
+        >>> a.add(3,4)
+        7
+        >>> a.ping()
+        'pong'
 
-'''
+    '''
     separator = '.'
     default_version = '2.0'
     default_timeout = 30
 
     def __init__(self, url, version=None, data=None,
-                 full_response=False, **kw):
-        self.__url = url
-        self.__version = version or self.__class__.default_version
+                 full_response=False, http=None, timeout=None, **kw):
+        self._url = url
+        self._version = version or self.__class__.default_version
         self._full_response = full_response
-        self.__data = data if data is not None else {}
-        self.local = AttributeDictionary()
-        self.setup(**kw)
-
-    def setup(self, http=None, timeout=None, **kw):
+        self._data = data if data is not None else {}
         if not http:
             timeout = timeout if timeout is not None else self.default_timeout
             http = HttpClient(timeout=timeout, **kw)
         http.headers['accept'] = 'application/json, text/*; q=0.5'
         http.headers['content-type'] = 'application/json'
-        self.local.http = http
+        self._http = http
 
     @property
     def url(self):
-        return self.__url
-
-    @property
-    def http(self):
-        return self.local.http
+        return self._url
 
     @property
     def version(self):
-        return self.__version
+        return self._version
+
+    @property
+    def _loop(self):
+        return self._http._loop
 
     def makeid(self):
         '''Can be re-implemented by your own Proxy'''
@@ -187,42 +181,25 @@ Lets say your RPC server is running at ``http://domain.name.com/``::
     def __getattr__(self, name):
         return JsonCall(self, name)
 
-    def timeit(self, func, times, *args, **kwargs):
-        '''Usefull little utility for timing responses from server. The
-usage is simple::
-
-    >>> from pulsar.apps import rpc
-    >>> p = rpc.JsonProxy('http://127.0.0.1:8060')
-    >>> p.timeit('ping',10)
-    0.56...
-    '''
-        func = getattr(self, func)
-        return multi_async((func(*args, **kwargs) for t in range(times)))
-
+    @task
     def _call(self, name, *args, **kwargs):
         data = self._get_data(name, *args, **kwargs)
         body = json.dumps(data).encode('utf-8')
-        resp = self.http.post(self.url, data=body)
+        resp = yield self._http.post(self._url, data=body)
         if self._full_response:
-            return resp
-        res = resp.on_finished.add_callback(self._end_call)
-        return res.result if self.http.force_sync else res
-
-    def _end_call(self, resp):
-        content = resp.decode_content()
-        if resp.is_error:
-            if 'error' in content:
-                return self.loads(content)
-            else:
-                resp.raise_for_status()
+            coroutine_return(resp)
         else:
-            return self.loads(content)
+            content = resp.decode_content()
+            if resp.is_error:
+                if 'error' not in content:
+                    resp.raise_for_status()
+            coroutine_return(self.loads(content))
 
     def _get_data(self, func_name, *args, **kwargs):
         id = self.makeid()
         params = self.get_params(*args, **kwargs)
         data = {'method': func_name, 'params': params, 'id': id,
-                'jsonrpc': self.__version}
+                'jsonrpc': self._version}
         return data
 
     def get_params(self, *args, **kwargs):
@@ -231,7 +208,7 @@ usage is simple::
         Mixing positional and named parameters in one
         call is not possible.
         '''
-        kwargs.update(self.__data)
+        kwargs.update(self._data)
         if args and kwargs:
             raise ValueError('Cannot mix positional and named parameters')
         if args:
