@@ -417,6 +417,14 @@ class TestShowLeaks(TestOption):
     """
 
 
+class TestPep8(TestOption):
+    name = "pep8"
+    flags = ['--pep8']
+    nargs = '*'
+    validator = pulsar.validate_list
+    desc = """Run pep8"""
+
+
 class TestSuite(tasks.TaskQueue):
     '''An asynchronous test suite which works like a task queue.
 
@@ -506,6 +514,12 @@ class TestSuite(tasks.TaskQueue):
                 stream.writeln(tag)
             stream.writeln('')
             return False
+        elif self.cfg.pep8:
+            msg, code = pep8_run(self.cfg.pep8)
+            stream.writeln(msg)
+            if code:
+                sys.exit(code)
+            return False
 
     def monitor_start(self, monitor):
         '''When the monitor starts load all test classes into the queue'''
