@@ -1,8 +1,8 @@
 from functools import reduce
-from asyncio import Queue, QueueFull
 
 from pulsar.utils.internet import is_socket_closed
 
+from .access import asyncio
 from .futures import coroutine_return, AsyncObject, future_timeout
 from .protocols import Producer
 
@@ -22,7 +22,7 @@ class Pool(AsyncObject):
         self._creator = creator
         self._closed = False
         self._timeout = timeout
-        self._queue = Queue(maxsize=pool_size, loop=loop)
+        self._queue = asyncio.Queue(maxsize=pool_size, loop=loop)
         self._connecting = 0
         self._loop = self._queue._loop
         self._in_use_connections = set()
@@ -63,7 +63,7 @@ class Pool(AsyncObject):
         The connection is either a new one or retrieved from the
         :attr:`available` connections in the pool.
 
-        :return: a :class:`.Future` resulting in the connection.
+        :return: a :class:`~asyncio.Future` resulting in the connection.
         '''
         assert not self._closed
         return PoolConnection.checkout(self)
@@ -103,8 +103,7 @@ class Pool(AsyncObject):
         if connection is None:
             connection = yield self._get()
         else:
-            if is_socket_closed(connection.sock):
-                connection.close()
+            if self.is_connection_closed(connection):
                 connection = yield self._get()
             else:
                 self._in_use_connections.add(connection)
@@ -114,10 +113,16 @@ class Pool(AsyncObject):
         if not self._closed:
             try:
                 self._queue.put_nowait(None if discard else conn)
-            except QueueFull:
+            except asyncio.QueueFull:
                 conn.close()
         self._in_use_connections.discard(conn)
 
+    def is_connection_closed(self, connection):
+        if is_socket_closed(connection.sock):
+            connection.close()
+            return True
+        return False
+
     def info(self, message=None, level=None):   # pragma    nocover
         if self._queue._maxsize != 2:
             return
